View source: R/robust_mapping.R
| robust.percapita | R Documentation |
Estimate robust per capita rates from a event count map (numerator) and a reference population map (denominator); both need to be SpatRaster grids with the same dimensions and covering the same extent. Event count map can be generated using robust.grid or robust.quadcount from a point set.
robust.percapita(numerator, denominator, bd = NULL, weighted = FALSE)
numerator |
an event count grid (SpatRaster) |
denominator |
a reference population map grid (SpatRaster), of the same dimensions, extent and resolution as numerator. |
bd |
bandwidth to be used by the GWR model. If NULL (default), bandwidth is estimated by cross-validation (using spgwr::gwr.sel()) |
weighted |
if true, denominator is used also as weights for the residuals in a Weighted Least Squares fashion. The rational is that areas with a greater denominator (e.g. more individuals experiencing a per capita rate) should have greater weight in the estimation of the rate. |
Rafael G. Ramos (main proponent and coder)
Ramos, R. G. (2021). Improving victimization risk estimation: A geographically weighted regression approach. ISPRS International Journal of Geo-Information, 10(6), 364.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.