View source: R/robust_mapping.R
| robust.timeslices | R Documentation |
Improves the rates per cells for each timeslice by considering information from the other slices. For each location, model (auto.arima only for now) is estimated for the corresponding time series. The predicted value at that cell-time is assigned as the improved, more robust rate. More formal validation is still required, but simulation tests I've ran show that it does yield better estimates.
robust.timeslices(observed_counts_timestamp, verbose = FALSE)
observed_counts_timestamp |
stack of rasters to be processed |
verbose |
whether to print messages while running the function or not |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.